==> ejc-settle-impl-3.0.0-20240617.053114-44-sources.jar: com/ejianc/business/settle/bean/SettlementCenterUserProjectMainEntity.java <==
package com.ejianc.business.settle.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算中心人员主信息
 * 
 * @author generator
 * 
 */
 @TableName("settlement_center_user_project_main")
public class SettlementCenterUserProjectMainEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="user_id")
    private Long userId; // 人员id
    @TableField(value="user_name")
    private String userName; // 用户名称
    @TableField(value="user_code")
    private String userCode; // 用户账号
    @TableField(value="org_id")
    private Long orgId; // 结算中心组织ID
    @TableField(value="major")
    private Integer major; // 结算中心专业 0土建、1机务、2电仪 使用方式1
    @TableField(value="roles")
    private String roles; // 结算中心角色 节点1,节点2,节点3,节点4,节点5,节点6,节点7 使用方式1,2
    
    
    

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Integer getMajor() {
        return major;
    }

    public void setMajor(Integer major) {
        this.major = major;
    }
    public String getRoles() {
        return roles;
    }

    public void setRoles(String roles) {
        this.roles = roles;
    }
    
}

==> ejc-settle-impl-3.0.0-20240708.072402-71-sources.jar: com/ejianc/business/settle/bean/SettlementCenterUserProjectMainEntity.java <==
package com.ejianc.business.settle.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算中心人员主信息
 * 
 * @author generator
 * 
 */
 @TableName("settlement_center_user_project_main")
public class SettlementCenterUserProjectMainEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="user_id")
    private Long userId; // 人员id
    @TableField(value="user_name")
    private String userName; // 用户名称
    @TableField(value="user_code")
    private String userCode; // 用户账号
    @TableField(value="org_id")
    private Long orgId; // 结算中心组织ID
    @TableField(value="major")
    private Integer major; // 结算中心专业 0土建、1机务、2电仪 使用方式1
    @TableField(value="roles")
    private String roles; // 结算中心角色 节点1,节点2,节点3,节点4,节点5,节点6,节点7 使用方式1,2
    @TableField(value = "project_id")
    private Long projectId; // 项目id
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "version")
    private Integer version; // 版本

    @Override
    public Integer getVersion() {
        return version;
    }

    @Override
    public void setVersion(Integer version) {
        this.version = version;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Integer getMajor() {
        return major;
    }

    public void setMajor(Integer major) {
        this.major = major;
    }
    public String getRoles() {
        return roles;
    }

    public void setRoles(String roles) {
        this.roles = roles;
    }
    
}
